==> fillets-ng-data_0.7.1.orig.tar.gz: fillets-ng-data-0.7.1/script/creatures/dialogs_nl.lua <==

dialogId("kor-m-podivej", "font_small", "Look at all these lobsters...")
dialogStr("Moet je al die kreeften zie...")


dialogId("kor-v-spitu", "font_big", "They sleep for thousands of years... in eternal stillness...")
dialogStr("Die slapen duizend jaar lang... voor eeuwig...")


dialogId("kor-m-avlada", "font_small", "...and the government tries to cover it up.")
dialogStr("...en de regering probeert het in de doofpot te stoppen.")


dialogId("kor-v-nicje", "font_big", "...nothing can wake them up...")
dialogStr("...niets kan ze wakker maken...")


dialogId("kor-m-pokud", "font_small", "Unless we activate that octopus.")
dialogStr("Behalve als we die oktopus een duwtje geven.")


dialogId("kor-v-podivej", "font_big", "Look, everything here is so still and quiet.")
dialogStr("Kijk, het is hier allemaal zo rustig en stil.")


dialogId("kor-m-vzdyt", "font_small", "But the anemones are moving.")
dialogStr("De zeeannemonen bewegen wel.")


dialogId("kor-v-treba", "font_big", "Maybe they`re in the throes of death.")
dialogStr("Misschien zijn het stuiptrekkingen.")


dialogId("kor-v-shledavam", "font_big", "I find a certain symbolism in that.")
dialogStr("Dat heeft een bepaald soort symboliek.")


dialogId("kor-v-bermudy", "font_big", "That`s interesting. This type of coral normally grows only in the Bermuda Triangle.")
dialogStr("Dat is interessant. Dit soort koraal groeit normaal alleen in de Bermuda Driehoek.")


dialogId("kor-v-inteligentni", "font_big", "Did you know that some types of coral are almost as intelligent as fish?")
dialogStr("Wist je dat sommige koralen bijna zo intelligent zijn als vissen?")


dialogId("kor-v-jedovate", "font_big", "Be careful, most types of coral are poisonous.")
dialogStr("Voorzichtig. De meeste soorten koraal zijn giftig.")


dialogId("kor-m-dusi", "font_small", "What do you think, is there such a thing as a 'coral-soul`?")
dialogStr("Wat denk je, hebben koralen een ziel?")


dialogId("kor-m-pocit", "font_small", "Do you have the feeling that those coral are watching us?")
dialogStr("Heb je niet het gevoel dat die stukken koraal ons bespieden?")


dialogId("kor-m-bizarni", "font_small", "I wonder why the coral have such a bizarre shape.")
dialogStr("Ik vraag me af waarom de koralen hier zulke rare vormen hebben.")


dialogId("kor-v-juchacka", "font_big", "That was some number, wasn`t it?")
dialogStr("Dat was geen slecht nummer, vond je niet?")


dialogId("kor-m-hraje", "font_small", "Yeah, he`s a great player.")
dialogStr("Jeetje, hij speelt goed.")


dialogId("kor-v-odvaz", "font_big", "That`s cool. What if we pushed him again?")
dialogStr("Gaaf. Wat als we hem nog een duwtje geven?")


dialogId("kor-m-vsimlsis", "font_small", "Did you see what the lobsters were doing?")
dialogStr("Zag je wat de krabben deden?")


dialogId("kor-v-avidelas", "font_big", "And how those anemones were dancing?")
dialogStr("En hoe de annemonen dansten?")


dialogId("kor-m-tovis", "font_small", "Well, you know, it`s not all that much fun down here at the bottom of the ocean.")
dialogStr("Nou ja, het is wel een beetje saai hier op de oceaanbodem.")


dialogId("kor-v-vali", "font_big", "He`s good, isn`t he?")
dialogStr("Hij is goed, zeg.")


dialogId("kor-m-nachob", "font_small", "Not bad for an octopus...")
dialogStr("Niet slecht voor een oktopus...")


dialogId("kor-m-jinou", "font_small", "Do you think he knows any other tune?")
dialogStr("Zou hij nog een ander deuntje kennen?")


dialogId("kor-m-neprehani", "font_small", "Don`t you think we`ve had enough already?")
dialogStr("Denk je niet dat we hier nu wel genoeg van hebben?")


dialogId("kor-m-lezekrkem", "font_small", "I`m getting sick of it...")
dialogStr("Ik ben hem zat...")


dialogId("kor-v-lezekrkem", "font_big", "I`m sick and tired of it...")
dialogStr("Ik heb er schoon genoeg van...")


dialogId("kor-v-kostice", "font_big", "I`m fed up to the gills with this.")
dialogStr("Dat deuntje begin ik goed zat te worden.")


dialogId("kor-v-odsud", "font_big", "I can`t budge this from where I am. I`d have to try to move it from the left side.")
dialogStr("Ik krijg dit niet los van hieraf. Ik zou het van de linker kant moeten proberen.")


dialogId("kor-m-budesmuset", "font_small", "Well you`ll have to go that way through those anemones.")
dialogStr("Dan moet je wel langs de annemonen zien te komen.")


dialogId("kor-m-neniono", "font_small", "That`s not what I had in mind...")
dialogStr("Ik had iets anders in gedachten...")


dialogId("kor-m-tudiru", "font_small", "We should have plugged that hole beforehand.")
dialogStr("We hadden die kuil vantevoren op moeten vullen.")

==> fillets-ng-data_0.8.0.orig.tar.gz: fillets-ng-data-0.8.0/script/creatures/dialogs_nl.lua <==

dialogId("kor-m-podivej", "font_small", "Look at all these lobsters...")
dialogStr("Moet je al die kreeften zie...")


dialogId("kor-v-spitu", "font_big", "They sleep for thousands of years... in eternal stillness...")
dialogStr("Die slapen duizend jaar lang... eeuwige rust...")


dialogId("kor-m-avlada", "font_small", "...and the government tries to cover it up.")
dialogStr("...en de regering probeert het in de doofpot te stoppen.")


dialogId("kor-v-nicje", "font_big", "...nothing can wake them up...")
dialogStr("...niets kan ze wakker maken...")


dialogId("kor-m-pokud", "font_small", "Unless we activate that octopus.")
dialogStr("Behalve als we die oktopus een duwtje geven.")


dialogId("kor-v-podivej", "font_big", "Look, everything here is so still and quiet.")
dialogStr("Kijk, het is hier allemaal zo rustig en stil.")


dialogId("kor-m-vzdyt", "font_small", "But the anemones are moving.")
dialogStr("De zeeannemonen bewegen wel.")


dialogId("kor-v-treba", "font_big", "Maybe they’re in the throes of death.")
dialogStr("Misschien zijn het stuiptrekkingen.")


dialogId("kor-v-shledavam", "font_big", "I find a certain symbolism in that.")
dialogStr("Dat heeft een bepaald soort symboliek.")


dialogId("kor-v-bermudy", "font_big", "That’s interesting. This type of coral normally grows only in the Bermuda Triangle.")
dialogStr("Dat is interessant. Dit soort koraal groeit normaal alleen in de Bermuda Driehoek.")


dialogId("kor-v-inteligentni", "font_big", "Did you know that some types of coral are almost as intelligent as fish?")
dialogStr("Wist je dat sommige koralen bijna zo intelligent zijn als vissen?")


dialogId("kor-v-jedovate", "font_big", "Be careful, most types of coral are poisonous.")
dialogStr("Voorzichtig. De meeste soorten koraal zijn giftig.")


dialogId("kor-m-dusi", "font_small", "What do you think, is there such a thing as a 'coral-soul’?")
dialogStr("Wat denk je, hebben koralen een ziel?")


dialogId("kor-m-pocit", "font_small", "Do you have the feeling that those coral are watching us?")
dialogStr("Heb je niet het gevoel dat die stukken koraal naar ons zitten te kijken?")


dialogId("kor-m-bizarni", "font_small", "I wonder why the coral have such a bizarre shape.")
dialogStr("Ik vraag me af waarom de koralen hier zulke rare vormen hebben.")


dialogId("kor-v-juchacka", "font_big", "That was some number, wasn’t it?")
dialogStr("Dat was geen slecht nummer, vond je niet?")


dialogId("kor-m-hraje", "font_small", "Yeah, he’s a great player.")
dialogStr("Ja, hij speelt goed.")


dialogId("kor-v-odvaz", "font_big", "That’s cool. What if we pushed him again?")
dialogStr("Gaaf. Wat als we hem nog een duwtje geven?")


dialogId("kor-m-vsimlsis", "font_small", "Did you see what the lobsters were doing?")
dialogStr("Zag je wat de krabben deden?")


dialogId("kor-v-avidelas", "font_big", "And how those anemones were dancing?")
dialogStr("En hoe de annemonen dansten?")


dialogId("kor-m-tovis", "font_small", "Well, you know, it’s not all that much fun down here at the bottom of the ocean.")
dialogStr("Nou ja, het is wel een beetje saai hier op de oceaanbodem.")


dialogId("kor-v-vali", "font_big", "He’s good, isn’t he?")
dialogStr("Hij is goed, zeg.")


dialogId("kor-m-nachob", "font_small", "Not bad for an octopus...")
dialogStr("Niet slecht voor een oktopus...")


dialogId("kor-m-jinou", "font_small", "Do you think he knows any other tune?")
dialogStr("Zou hij nog een ander deuntje kennen?")


dialogId("kor-m-neprehani", "font_small", "Don’t you think we’ve had enough already?")
dialogStr("Denk je niet dat we hier nu wel genoeg van hebben?")


dialogId("kor-m-lezekrkem", "font_small", "I’m getting sick of it...")
dialogStr("Ik ben hem zat...")


dialogId("kor-v-lezekrkem", "font_big", "I’m sick and tired of it...")
dialogStr("Ik heb er schoon genoeg van...")


dialogId("kor-v-kostice", "font_big", "I’m fed up to the gills with this.")
dialogStr("Ik begin dat deuntje goed beu te worden.")


dialogId("kor-v-odsud", "font_big", "I can’t budge this from where I am. I’d have to try to move it from the left side.")
dialogStr("Ik krijg dit niet los van hieraf. Ik zou het van de linker kant moeten proberen.")


dialogId("kor-m-budesmuset", "font_small", "Well you’ll have to go that way through those anemones.")
dialogStr("Dan moet je wel langs de annemonen zien te komen.")


dialogId("kor-m-neniono", "font_small", "That’s not what I had in mind...")
dialogStr("Ik had iets anders in gedachten...")


dialogId("kor-m-tudiru", "font_small", "We should have plugged that hole beforehand.")
dialogStr("We hadden die kuil vantevoren op moeten vullen.")
